@@ -672,21 +672,25 @@ AbstractType::Ptr stripType(KDevelop::AbstractType::Ptr type, DUContext* ctx) {
   return type;
 }
 
-QString shortenedTypeString(KDevelop::Declaration* decl, KDevelop::DUContext* ctx, int desiredLength, KDevelop::QualifiedIdentifier stripPrefix) {
+AbstractType::Ptr typeForShortenedString (Declaration* decl)
+{
   AbstractType::Ptr type = decl->abstractType();
   if(decl->isTypeAlias()) {
       if(type.cast<TypeAliasType>())
         type = type.cast<TypeAliasType>()->type();
   }
-  
+
   if(decl->isFunctionDeclaration()) {
     FunctionType::Ptr funType = decl->type<FunctionType>();
     if(!funType)
-      return QString();
+      return AbstractType::Ptr();
     type = funType->returnType();
   }
-  
-  return shortenedTypeString(type, ctx, desiredLength, stripPrefix);
+  return type;
+}
+
+QString shortenedTypeString(KDevelop::Declaration* decl, KDevelop::DUContext* ctx, int desiredLength, KDevelop::QualifiedIdentifier stripPrefix) {
+  return shortenedTypeString(typeForShortenedString(decl), ctx, desiredLength, stripPrefix);
 }
 
 QString simplifiedTypeString(KDevelop::AbstractType::Ptr type, KDevelop::DUContext* visibilityFrom) {
@@ -820,7 +824,17 @@ QualifiedIdentifier stripPrefixes(DUContext* ctx, QualifiedIdentifier id)
   return id;
 }
 
-KDevelop::IndexedIdentifier castIdentifier(Identifier("operator{...cast...}"));
-KDevelop::IndexedIdentifier unnamedNamespaceIdentifier(Identifier("unnamed{...namespace...}"));
+const KDevelop::IndexedIdentifier& castIdentifier()
+{
+  static const KDevelop::IndexedIdentifier id(Identifier("operator{...cast...}"));
+  return id;
+}
+
+const KDevelop::IndexedIdentifier& unnamedNamespaceIdentifier()
+{
+  static const KDevelop::IndexedIdentifier id(Identifier("unnamed{...namespace...}"));
+  return id;
+}
+
 }
 
