@@ -162,7 +162,7 @@ QList<ProjectFolderItem*> CustomMakeManager::parse(KDevelop::ProjectFolderItem *
             folder_list.append( cmfi );
 //             d->m_testItems.append( cmfi ); // debug
             if( topItem )
-                topItem->fsWatcher()->addDirectory( absFilePath, cmfi );
+                topItem->fsWatcher()->addDirectory( cmfi );
         }
         //TODO: make filtering generic
         else if ( fileInfo.isFile() && !fileName.endsWith('~') && !fileName.endsWith(".o") )
@@ -172,8 +172,8 @@ QList<ProjectFolderItem*> CustomMakeManager::parse(KDevelop::ProjectFolderItem *
                 new KDevelop::ProjectFileItem( item->project(), fileUrl, item );
             if( topItem && fileName == "Makefile" )
             {
-                topItem->fsWatcher()->addFile( absFilePath, fileItem );
-                QStringList targetlist = this->parseCustomMakeFile( KUrl(absFilePath) );
+                topItem->fsWatcher()->addFile( fileItem );
+                QStringList targetlist = this->parseCustomMakeFile( fileUrl );
                 foreach( const QString &target, targetlist )
                 {
                     new CustomMakeTargetItem( item->project(), target, item );
@@ -204,7 +204,7 @@ KDevelop::ProjectFolderItem* CustomMakeManager::import(KDevelop::IProject *proje
     if( !project ) return NULL;
 //     return new KDevelop::ProjectFolderItem( project, project->folder().pathOrUrl(), NULL );
     CustomMakeFolderItem *item = new CustomMakeFolderItem( this, project, project->folder(), NULL );
-    item->fsWatcher()->addDirectory( project->folder().toLocalFile(), item );
+    item->fsWatcher()->addDirectory( item );
 
     return item;
 }
